import React , { useState } from 'react';
import { Link } from '@magento/venia-drivers';
import defaultClasses from './megaMenu.css';
import {useMegaMenu} from '../../peregrine/lib/talons/MegaMenuAdvance/useMegaMenu';
import GET_MEGAMENU_QUERY from '../../queries/getMegaMenu.graphql';
import MenuCategories from './menuCategories.js';
import MenuCustomItems from './menuCustomItems.js';
import ProductSlider from './productSlider.js';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faChevronDown } from '@fortawesome/free-solid-svg-icons';
const MegaMenuAdvance = () => {
    const [showChild, setShowChild] = useState('');
    const { megaMenuData } = useMegaMenu({
        query: GET_MEGAMENU_QUERY
    });    
    const menuItemsData = megaMenuData.items ? JSON.parse(megaMenuData.items) : [];   
    const menuItems = menuItemsData.map((val, index) => {    
        return (
            <li className={defaultClasses.item + ' ' + defaultClasses.haschild} key={index}>
                <div onMouseEnter={e=>{setShowChild(val.title)}} onMouseLeave={e=>{setShowChild('')}}>
                    <i class={val.icon}></i>
                    {val.type=='custom_link' ? <Link style={{color:`${val.color}`}} to={val.url}>{val.title}</Link> : <Link style={{color:`${val.color}`}}>{val.title}</Link>}
                </div>
                {(
                    showChild==val.title && 
                    (val.children || val.type=='category')) &&
                <div onMouseEnter={e=>{setShowChild(val.title)}} onMouseLeave={e=>{setShowChild('')}}  className={`${megaMenuData.animation_type}` +' '+defaultClasses.sub_menu + ' ' + defaultClasses.megamenu_wrap + ' ' + "container-fluid"}>
                    <div className={"row"}>
                        <div className={"col-7 col-lg-7 col-md-6" + ' ' + defaultClasses.megamenu_block_width80 + ' ' + defaultClasses.menu_wrap}>
                            <div className={defaultClasses.menu_inner_wrap}>
                                {val.type=='category' ? 
                                <MenuCategories parentCategoryId={val.parent_cat_id} isParentCategory={true} /> :
                                <MenuCustomItems customItems={val.children} isParentItem={true}/>}
                            </div>
                        </div>
                        <div className={"col-5 col-md-6 col-lg-5" + ' ' + defaultClasses.megamenu_block_width20 + ' ' + defaultClasses.static_image_block}>
                            <div className={defaultClasses.megamenu_banner_media}>
                                {val.column2_pro_slider_skus && <ProductSlider skus={val.column2_pro_slider_skus}/>}
                                {val.column2_banner_img &&
                                <div className={defaultClasses.megamenu_bnnerimage_wrap}>
                                    <img className={defaultClasses.megamenu_bnnerimage} src={val.column2_banner_img} alt="megamenu banner" />
                                </div>}
                            </div>
                        </div>
                    </div>
                </div>}

            </li>
        )
    });

    return(
        <>
            <div className={defaultClasses.main_navigation}>
            <div className="container">
                <div className="row">
                <div className="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                    <ul className={defaultClasses.ced_megamenu}>
                        {menuItems}
                    </ul>
                </div>
                </div>
            </div>
            </div>
        </>
    )
}
export default MegaMenuAdvance;